@@ -32,6 +32,8 @@ from sugar import env
 from sugar import util
 from sugar.bundle.bundle import Bundle, \
     MalformedBundleException, NotInstalledException
+from sugar.bundle.bundleversion import NormalizedVersion
+from sugar.bundle.bundleversion import InvalidVersionError
 
 
 class ActivityBundle(Bundle):
@@ -59,9 +61,8 @@ class ActivityBundle(Bundle):
         self._mime_types = None
         self._show_launcher = True
         self._tags = None
-        self._activity_version = 0
+        self._activity_version = '0'
         self._installation_time = os.stat(path).st_mtime
-        self._manifest = None
 
         info_file = self.get_file('activity/activity.info')
         if info_file is None:
@@ -75,74 +76,6 @@ class ActivityBundle(Bundle):
         if self._local_name == None:
             self._local_name = self._name
 
-    def _get_manifest(self):
-        if self._manifest is None:
-            self._manifest = self._read_manifest()
-        return self._manifest
-
-    manifest = property(_get_manifest, None, None,
-        "NOTICE: this property is potentially quite slow, so better make sure "
-        "that it's not called at performance-critical points like shell or "
-        "activity startup.")
-
-    def _raw_manifest(self):
-        f = self.get_file("MANIFEST")
-        if not f:
-            logging.warning("Activity directory lacks a MANIFEST file.")
-            return []
-
-        ret = [line.strip() for line in f.readlines()]
-        f.close()
-        return ret
-
-    def _read_manifest(self):
-        """return a list with the lines in MANIFEST, with invalid lines
-        replaced by empty lines.
-
-        Since absolute order carries information on file history, it should
-        be preserved. For instance, when renaming a file, you should leave
-        the new name on the same line as the old one.
-        """
-        logging.debug('STARTUP: Reading manifest')
-        lines = self._raw_manifest()
-
-        # Remove trailing newlines, they do not help keep absolute position.
-        while lines and lines[-1] == "":
-            lines = lines[:-1]
-
-        for num, line in enumerate(lines):
-            if not line:
-                continue
-
-            # Remove duplicates
-            if line in lines[0:num]:
-                lines[num] = ""
-                logging.warning('Bundle %s: duplicate entry in MANIFEST: %s',
-                    self._name, line)
-                continue
-
-            # Remove MANIFEST
-            if line == "MANIFEST":
-                lines[num] = ""
-                logging.warning('Bundle %s: MANIFEST includes itself: %s',
-                    self._name, line)
-
-            # Remove invalid files
-            if not self.is_file(line):
-                lines[num] = ""
-                logging.warning('Bundle %s: invalid entry in MANIFEST: %s',
-                    self._name, line)
-
-        return lines
-
-    def get_files(self, manifest = None):
-        files = [line for line in (manifest or self.manifest) if line]
-
-        if self.is_file('MANIFEST'):
-            files.append('MANIFEST')
-
-        return files
-
     def _parse_info(self, info_file):
         cp = ConfigParser()
         cp.readfp(info_file)
@@ -197,11 +130,12 @@ class ActivityBundle(Bundle):
         if cp.has_option(section, 'activity_version'):
             version = cp.get(section, 'activity_version')
             try:
-                self._activity_version = int(version)
-            except ValueError:
+                NormalizedVersion(version)
+            except InvalidVersionError:
                 raise MalformedBundleException(
                     'Activity bundle %s has invalid version number %s' %
                     (self._path, version))
+            self._activity_version = version
 
     def _get_linfo_file(self):
         lang = locale.getdefaultlocale()[0]
@@ -306,48 +240,20 @@ class ActivityBundle(Bundle):
         """Get whether there should be a visible launcher for the activity"""
         return self._show_launcher
 
-    def install(self, install_dir=None, strict_manifest=False):
+    def install(self, install_dir=None):
         if install_dir is None:
             install_dir = env.get_user_activities_path()
 
         self._unzip(install_dir)
 
         install_path = os.path.join(install_dir, self._zip_root_dir)
-
-        # List installed files
-        manifestfiles = self.get_files(self._raw_manifest())
-        paths = []
-        for root, dirs_, files in os.walk(install_path):
-            rel_path = root[len(install_path) + 1:]
-            for f in files:
-                paths.append(os.path.join(rel_path, f))
-
-        # Check the list against the MANIFEST
-        for path in paths:
-            if path in manifestfiles:
-                manifestfiles.remove(path)
-            elif path != "MANIFEST":
-                logging.warning('Bundle %s: %s not in MANIFEST', self._name,
-                    path)
-                if strict_manifest:
-                    os.remove(os.path.join(install_path, path))
-
-        # Is anything in MANIFEST left over after accounting for all files?
-        if manifestfiles:
-            err = ("Bundle %s: files in MANIFEST not included: %s"%
-                   (self._name, str(manifestfiles)))
-            if strict_manifest:
-                raise MalformedBundleException(err)
-            else:
-                logging.warning(err)
-
         self.install_mime_type(install_path)
 
         return install_path
 
     def install_mime_type(self, install_path):
-        ''' Update the mime type database and install the mime type icon
-        '''
+        """ Update the mime type database and install the mime type icon
+        """
         xdg_data_home = os.getenv('XDG_DATA_HOME',
                                   os.path.expanduser('~/.local/share'))
 
